Index: src/crankshaft/arm/lithium-codegen-arm.cc |
diff --git a/src/crankshaft/arm/lithium-codegen-arm.cc b/src/crankshaft/arm/lithium-codegen-arm.cc |
index b61b6d8b7dc142102f7400c8cf2b64b6731307dc..35ebf887d8617ae5b704793d4144cc77c99d1366 100644 |
--- a/src/crankshaft/arm/lithium-codegen-arm.cc |
+++ b/src/crankshaft/arm/lithium-codegen-arm.cc |
@@ -3152,11 +3152,13 @@ void LCodeGen::DoLoadKeyedFixedArray(LLoadKeyed* instr) { |
__ b(ne, &done); |
if (info()->IsStub()) { |
// A stub can safely convert the hole to undefined only if the array |
// protector cell contains (Smi) Isolate::kArrayProtectorValid. Otherwise |
// it needs to bail out. |
- __ LoadRoot(result, Heap::kArrayProtectorRootIndex); |
+ __ LoadRoot(result, Heap::kArrayElementsProtectorRootIndex); |
__ ldr(result, FieldMemOperand(result, Cell::kValueOffset)); |
- __ cmp(result, Operand(Smi::FromInt(Isolate::kArrayProtectorValid))); |
+ __ cmp(result, |
+ Operand(Smi::FromInt(Isolate::kArrayElementsProtectorValid))); |
DeoptimizeIf(ne, instr, Deoptimizer::kHole); |
} |
__ LoadRoot(result, Heap::kUndefinedValueRootIndex); |
@@ -3152,11 +3152,13 @@ void LCodeGen::DoLoadKeyedFixedArray(LLoadKeyed* instr) { |
if (info()->IsStub()) { |
// A stub can safely convert the hole to undefined only if the array |
- // protector cell contains (Smi) Isolate::kArrayProtectorValid. Otherwise |
+ // protector cell contains (Smi) Isolate::kArrayElementsProtectorValid. |
+ // Otherwise |
// it needs to bail out. |